pub struct EscapeInfo {
pub escape_regex: Regex,
pub has_captures: bool,
pub escape_captures: Option<CaptureMapping>,
/* private fields */
}Expand description
Information about the escape pattern for an embed operation.
The escape regex takes strict precedence over all other patterns,
unlike with_prototype where patterns compete equally.
Fields
escape_regex: Regexhas_captures: boolescape_captures: Option<CaptureMapping>Trait Implementations
Sourceimpl Clone for EscapeInfo
impl Clone for EscapeInfo
Sourcefn clone(&self) -> EscapeInfo
fn clone(&self) -> EscapeInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EscapeInfo
impl Debug for EscapeInfo
Sourceimpl<'de> Deserialize<'de> for EscapeInfo
impl<'de> Deserialize<'de> for EscapeInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EscapeInfo
impl PartialEq for EscapeInfo
Sourceimpl Serialize for EscapeInfo
impl Serialize for EscapeInfo
impl Eq for EscapeInfo
impl StructuralPartialEq for EscapeInfo